@@ -7,16 +7,16 @@ from jass.game.game_observation import GameObservation
 
 class Agent:
     """
-    Agent to act as a player in a match of jass.
+    Agent to act as a player in a game of jass.
     """
     def action_trump(self, obs: GameObservation) -> int:
         """
         Determine trump action for the given observation
         Args:
-            obs: the match observation, it must be in a state for trump selection
+            obs: the game observation, it must be in a state for trump selection
 
         Returns:
-            selected trump as encoded in jass.match.const or jass.match.const.PUSH
+            selected trump as encoded in jass.game.const or jass.game.const.PUSH
         """
         raise NotImplementedError
 
@@ -25,10 +25,9 @@ class Agent:
         Determine the card to play.
 
         Args:
-            obs: the match observation
+            obs: the game observation
 
         Returns:
-            the card to play, int encoded as defined in jass.match.const
+            the card to play, int encoded as defined in jass.game.const
         """
         raise NotImplementedError
-
