@@ -5,11 +5,12 @@
 import logging
 import sys
 from datetime import datetime
-from typing import List
+from typing import List, Union
 
 import numpy as np
 
 from jass.agents.agent import Agent
+from jass.agents.agent_cheating import AgentCheating
 from jass.arena.dealing_card_random_strategy import DealingCardRandomStrategy
 from jass.arena.dealing_card_strategy import DealingCardStrategy
 from jass.game.const import NORTH, EAST, SOUTH, WEST, DIAMONDS, MAX_TRUMP, PUSH, next_player
@@ -35,7 +36,8 @@ class Arena:
                  dealing_card_strategy: DealingCardStrategy = None,
                  print_every_x_games: int = 5,
                  check_move_validity=True,
-                 save_filename=None):
+                 save_filename=None,
+                 cheating_mode=False):
         """
 
         Args:
@@ -44,7 +46,9 @@ class Arena:
             print_every_x_games: print results every x games
             check_move_validity: True if moves from the agents should be checked for validity
             save_filename: True if results should be save
+            cheating_mode: True if agents will receive the full game state
         """
+        self._cheating_mode = cheating_mode
         self._logger = logging.getLogger(__name__)
 
         self._nr_games_played = 0
@@ -57,13 +61,13 @@ class Arena:
             self._dealing_card_strategy = dealing_card_strategy
 
         # the players
-        self._players: List[Agent or None] = [None, None, None, None]
+        self._players: List[Agent or AgentCheating or None] = [None, None, None, None]
 
         # player ids to use in saved games (if written)
         self._player_ids: List[int] = [0, 0, 0, 0]
 
         # the current game that is being played
-        self._game = GameSim(rule=RuleSchieber())
+        self._game = GameSim(rule=RuleSchieber())  # schieber rule is default
 
         # we store the points for each game
         self._points_team_0 = np.zeros(self._nr_games_to_play)
@@ -80,6 +84,12 @@ class Arena:
         else:
             self._save_games = False
 
+        # if cheating mode agents observation corresponds to the full game state
+        if self._cheating_mode:
+            self.get_agent_observation = lambda: self._game.state
+        else:
+            self.get_agent_observation = self._game.get_observation
+
     @property
     def nr_games_to_play(self):
         return self._nr_games_to_play
@@ -87,35 +97,35 @@ class Arena:
         # We define properties for the individual players to set/get them easily by name
 
     @property
-    def north(self) -> Agent:
+    def north(self) -> Union[Agent, AgentCheating]:
         return self._players[NORTH]
 
     @north.setter
-    def north(self, player: Agent):
+    def north(self, player: Union[Agent, AgentCheating]):
         self._players[NORTH] = player
 
     @property
-    def east(self) -> Agent:
+    def east(self) -> Union[Agent, AgentCheating]:
         return self._players[EAST]
 
     @east.setter
-    def east(self, player: Agent):
+    def east(self, player: Union[Agent, AgentCheating]):
         self._players[EAST] = player
 
     @property
-    def south(self) -> Agent:
+    def south(self) -> Union[Agent, AgentCheating]:
         return self._players[SOUTH]
 
     @south.setter
-    def south(self, player: Agent):
+    def south(self, player: Union[Agent, AgentCheating]):
         self._players[SOUTH] = player
 
     @property
-    def west(self) -> Agent:
+    def west(self) -> Union[Agent, AgentCheating]:
         return self._players[WEST]
 
     @west.setter
-    def west(self, player: Agent):
+    def west(self, player: Union[Agent, AgentCheating]):
         self._players[WEST] = player
 
     @property
@@ -144,7 +154,8 @@ class Arena:
         """
         return self._game.get_observation()
 
-    def set_players(self, north: Agent, east: Agent, south: Agent, west: Agent,
+    def set_players(self, north: Union[Agent, AgentCheating], east: Union[Agent, AgentCheating],
+                    south: Union[Agent, AgentCheating], west: Union[Agent, AgentCheating],
                     north_id=0, east_id=0, south_id=0, west_id=0) -> None:
         """
         Set the players.
@@ -158,6 +169,7 @@ class Arena:
             south_id: id to use for south in the save file
             west_id: id to use for west in the save file
         """
+
         self._players[NORTH] = north
         self._players[EAST] = east
         self._players[SOUTH] = south
@@ -167,6 +179,11 @@ class Arena:
         self._player_ids[SOUTH] = south_id
         self._player_ids[WEST] = west_id
 
+        if self._cheating_mode and not all([issubclass(type(x), AgentCheating) for x in self._players]):
+            raise AssertionError(f"All agents must be a subclass of {AgentCheating} in cheating mode.")
+        elif not self._cheating_mode and not all([issubclass(type(x), Agent) for x in self._players]):
+            raise AssertionError(f"All agents must be a subclass of {Agent} in non cheating mode.")
+
     def play_game(self, dealer: int) -> None:
         """
         Play a complete game (36 cards).
@@ -178,14 +195,15 @@ class Arena:
 
         # determine trump
         # ask first player
-        trump_action = self._players[self._game.state.player].action_trump(self._game.get_observation())
+
+        trump_action = self._players[self._game.state.player].action_trump(self.get_agent_observation())
         if trump_action < DIAMONDS or (trump_action > MAX_TRUMP and trump_action != PUSH):
             self._logger.error('Illegal trump (' + str(trump_action) + ') selected')
             raise RuntimeError('Illegal trump (' + str(trump_action) + ') selected')
         self._game.action_trump(trump_action)
         if trump_action == PUSH:
             # ask second player
-            trump_action = self._players[self._game.state.player].action_trump(self._game.get_observation())
+            trump_action = self._players[self._game.state.player].action_trump(self.get_agent_observation())
             if trump_action < DIAMONDS or trump_action > MAX_TRUMP:
                 self._logger.error('Illegal trump (' + str(trump_action) + ') selected')
                 raise RuntimeError('Illegal trump (' + str(trump_action) + ') selected')
@@ -193,11 +211,12 @@ class Arena:
 
         # play cards
         for cards in range(36):
-            obs = self._game.get_observation()
+            obs = self.get_agent_observation()
             card_action = self._players[self._game.state.player].action_play_card(obs)
             if self._check_moves_validity:
-                assert card_action in np.flatnonzero(self._game.rule.get_valid_cards_from_obs(obs)), \
-                    'Invalid card played!'
+                assert card_action in np.flatnonzero(self._game.rule.get_valid_actions_from_state(obs)) \
+                    if self._cheating_mode else \
+                    card_action in np.flatnonzero(self._game.rule.get_valid_cards_from_obs(obs)), 'Invalid card played!'
             self._game.action_play_card(card_action)
 
         # update results
